# Survey

If you use thumbor, please take 1 minute and answer [this survey](http://t.co/qPBLXJX0mi)? It's only 2 questions and one is multiple choice!!!

[<img src="https://raw.github.com/thumbor/thumbor/master/logo-thumbor.png">](https://github.com/thumbor/thumbor)

[<img src="https://secure.travis-ci.org/thumbor/thumbor.png?branch=master">](http://travis-ci.org/thumbor/thumbor)
[![Coverage Status](https://coveralls.io/repos/thumbor/thumbor/badge.svg?branch=master&service=github)](https://coveralls.io/github/thumbor/thumbor?branch=master)
[![Code Climate](https://codeclimate.com/github/thumbor/thumbor/badges/gpa.svg)](https://codeclimate.com/github/thumbor/thumbor)
[![Codacy Badge](https://api.codacy.com/project/badge/373e13c719c0417f84f0d7d363c9d539)](https://www.codacy.com/app/heynemann/thumbor)
[![Shields](https://img.shields.io/github/issues-pr-raw/thumbor/thumbor.svg)](https://github.com/thumbor/thumbor/pulls)
[![Shields](https://img.shields.io/github/issues-raw/thumbor/thumbor.svg)](https://github.com/thumbor/thumbor/issues)
[![PyPI](https://img.shields.io/pypi/v/thumbor.svg)](https://pypi.python.org/pypi/thumbor)
[![PyPI](https://img.shields.io/pypi/dm/thumbor.svg)](https://pypi.python.org/pypi/thumbor)
[![Bountysource](https://www.bountysource.com/badge/tracker?tracker_id=257692)](https://www.bountysource.com/trackers/257692-globocom-thumbor?utm_source=257692&utm_medium=shield&utm_campaign=TRACKER_BADGE)

thumbor is a smart imaging service. It enables on-demand [crop, resizing and flipping](http://thumbor.readthedocs.io/en/latest/crop_and_resize_algorithms.html) of images.

It also features a VERY smart detection of important points in the image for better cropping and resizing, using state-of-the-art face and feature detection algorithms (more on that in [Detection Algorithms](http://thumbor.readthedocs.io/en/latest/detection_algorithms.html)).

Using thumbor is very easy (after it is running). All you have to do is access it using an URL for an image, like this:

```
http://<thumbor-server>/300x200/smart/thumbor.readthedocs.io/en/latest/_images/logo-thumbor.png
```

That URL would show an image of the big brother brasil participants in 300x200 using smart crop.

There are several other options to the image URL configuration. You can check them in the [Usage page](http://thumbor.readthedocs.io/en/latest/usage.html).

For more information check [thumbor's
documentation](http://thumbor.readthedocs.org/en/latest/index.html "thumbor docs").

### Demo

You can see thumbor in action at http://thumborize.me/



Join the chat at https://gitter.im/thumbor/thumbor
